==> netw-ib-ox-ag_5.30.0.orig.tar.gz: netw-ib-ox-ag-5.30.0/src/netwib-src/src/netwib/net/priv/ip.h <==

/*-------------------------------------------------------------*/
netwib_err netwib_priv_ip_ip4_init_ip6(netwib_constip6 *pip6,
                                       netwib_ip4 *pip4);
netwib_err netwib_priv_ip_ip6_init_ip4(netwib_ip4 ip4,
                                       netwib_ip6 *pip6);

/*-------------------------------------------------------------*/
/* also accept "1.2.3" for "1.2.3.0" and "127" for "127.0.0.0" */
netwib_err netwib_priv_ip_init_sip4(netwib_conststring str,
                                    netwib_bool acceptnet,
                                    netwib_ip *pip);
netwib_err netwib_priv_ip_init_sip6(netwib_conststring str,
                                    netwib_ip *pip);
netwib_err netwib_priv_ip_init_hn4(netwib_conststring str,
                                   netwib_ip *pip);
netwib_err netwib_priv_ip_init_hn6(netwib_conststring str,
                                   netwib_ip *pip);

/*-------------------------------------------------------------*/
/* also accept "1.2.3" for "1.2.3.0" and "127" for "127.0.0.0" */
netwib_err netwib_priv_ip_init_bufnet(netwib_constbuf *pbuf,
                                      netwib_ip *pip);

/*-------------------------------------------------------------*/
netwib_err netwib_priv_ip_buf_append_ip4(netwib_constip *pip,
                                         netwib_buf *pbuf);
netwib_err netwib_priv_ip_buf_append_ip6(netwib_constip *pip,
                                         netwib_buf *pbuf);
netwib_err netwib_priv_ip_buf_append_hn(netwib_constip *pip,
                                        netwib_buf *pbuf);
netwib_err netwib_priv_ip_buf_append_hns(netwib_constip *pip,
                                         netwib_buf *pbuf);

/*-------------------------------------------------------------*/
netwib_err netwib_priv_ip_ip6_supported(netwib_bool *pyes);

/*-------------------------------------------------------------*/
netwib_err netwib_priv_ip_init_maskprefix(netwib_constip *pip,
                                          netwib_constip *pmask,
                                          netwib_uint32 prefix,
                                          netwib_ip *pipm);
netwib_err netwib_priv_ip_cmp_maskprefix(netwib_constip *pip1,
                                         netwib_constip *pip2,
                                         netwib_constip *pmask,
                                         netwib_uint32 prefix,
                                         netwib_cmp *pcmp);

/*-------------------------------------------------------------*/
netwib_err netwib_priv_ip_maskprefix_init_ipnet(netwib_constip *pip,
                                                netwib_constip *pnet,
                                                netwib_ip *pmask,
                                                netwib_uint32 *pprefix);
netwib_err netwib_priv_ip_maskprefix_init_sali(const netwib_priv_sockaddr *psa,
                                               netwib_uint32 supposedsalen,
                                               netwib_iptype supposediptype,
                                               netwib_ip *pmask,
                                               netwib_uint32 *pprefix);
#define netwib_priv_ip_maskprefix_init_sal(psa,supposedsalen,pmask,pprefix) netwib_priv_ip_maskprefix_init_sali(psa,supposedsalen,NETWIB_IPTYPE_UNKNOWN,pmask,pprefix)
#define netwib_priv_ip_maskprefix_init_sai(psa,supposediptype,pmask,pprefix) netwib_priv_ip_maskprefix_init_sali(psa,0xFFFFFFFFu,supposediptype,pmask,pprefix)
#define netwib_priv_ip_maskprefix_init_sa(psa,pmask,pprefix) netwib_priv_ip_maskprefix_init_sali(psa,0xFFFFFFFFu,NETWIB_IPTYPE_UNKNOWN,pmask,pprefix)

/*-------------------------------------------------------------*/
netwib_err netwib_priv_ip_prefix_init_mask(netwib_constip *pmask,
                                           netwib_uint32 *pprefix);

==> netw-ib-ox-ag_5.33.0.orig.tar.gz: netw-ib-ox-ag-5.33.0/src/netwib-src/src/netwib/net/priv/ip.h <==

/*-------------------------------------------------------------*/
netwib_err netwib_priv_ip_ip4_init_ip6(netwib_constip6 *pip6,
                                       netwib_ip4 *pip4);
netwib_err netwib_priv_ip_ip6_init_ip4(netwib_ip4 ip4,
                                       netwib_ip6 *pip6);

/*-------------------------------------------------------------*/
/* also accept "1.2.3" for "1.2.3.0" and "127" for "127.0.0.0" */
netwib_err netwib_priv_ip_init_sip4(netwib_conststring str,
                                    netwib_bool acceptnet,
                                    netwib_ip *pip);
netwib_err netwib_priv_ip_init_sip6(netwib_conststring str,
                                    netwib_ip *pip);
netwib_err netwib_priv_ip_init_hn4(netwib_conststring str,
                                   netwib_ip *pip);
netwib_err netwib_priv_ip_init_hn6(netwib_conststring str,
                                   netwib_ip *pip);

/*-------------------------------------------------------------*/
/* also accept "1.2.3" for "1.2.3.0" and "127" for "127.0.0.0" */
netwib_err netwib_priv_ip_init_bufnet(netwib_constbuf *pbuf,
                                      netwib_ip *pip);

/*-------------------------------------------------------------*/
netwib_err netwib_priv_ip_buf_append_ip4(netwib_constip *pip,
                                         netwib_buf *pbuf);
netwib_err netwib_priv_ip_buf_append_ip6(netwib_constip *pip,
                                         netwib_buf *pbuf);
netwib_err netwib_priv_ip_buf_append_hn(netwib_constip *pip,
                                        netwib_buf *pbuf);
netwib_err netwib_priv_ip_buf_append_hns(netwib_constip *pip,
                                         netwib_buf *pbuf);

/*-------------------------------------------------------------*/
netwib_err netwib_priv_ip_ip6_supported(netwib_bool *pyes);

/*-------------------------------------------------------------*/
netwib_err netwib_priv_ip_init_maskprefix(netwib_constip *pip,
                                          netwib_constip *pmask,
                                          netwib_uint32 prefix,
                                          netwib_ip *pipm);
netwib_err netwib_priv_ip_cmp_maskprefix(netwib_constip *pip1,
                                         netwib_constip *pip2,
                                         netwib_constip *pmask,
                                         netwib_uint32 prefix,
                                         netwib_cmp *pcmp);

/*-------------------------------------------------------------*/
netwib_err netwib_priv_ip_maskprefix_init_ipnet(netwib_constip *pip,
                                                netwib_constip *pnet,
                                                netwib_ip *pmask,
                                                netwib_uint32 *pprefix);
netwib_err netwib_priv_ip_maskprefix_init_sali(const netwib_priv_sockaddr_unalign *psa,
                                               netwib_uint32 supposedsalen,
                                               netwib_iptype supposediptype,
                                               netwib_ip *pmask,
                                               netwib_uint32 *pprefix);
#define netwib_priv_ip_maskprefix_init_sal(psa,supposedsalen,pmask,pprefix) netwib_priv_ip_maskprefix_init_sali(psa,supposedsalen,NETWIB_IPTYPE_UNKNOWN,pmask,pprefix)
#define netwib_priv_ip_maskprefix_init_sai(psa,supposediptype,pmask,pprefix) netwib_priv_ip_maskprefix_init_sali(psa,0xFFFFFFFFu,supposediptype,pmask,pprefix)
#define netwib_priv_ip_maskprefix_init_sa(psa,pmask,pprefix) netwib_priv_ip_maskprefix_init_sali(psa,0xFFFFFFFFu,NETWIB_IPTYPE_UNKNOWN,pmask,pprefix)

/*-------------------------------------------------------------*/
netwib_err netwib_priv_ip_prefix_init_mask(netwib_constip *pmask,
                                           netwib_uint32 *pprefix);
